import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.cancel_rent_response import CancelRentResponse
from smscx_client.model.data_number_lookup import DataNumberLookup
from smscx_client.model.get_inbound_sms_response import GetInboundSMSResponse
from smscx_client.model.get_rent_status_response import GetRentStatusResponse
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.number_lookup_response import NumberLookupResponse
from smscx_client.model.number_validate_response import NumberValidateResponse
from smscx_client.model.numbers_bulk_lookup_result import NumbersBulkLookupResult
from smscx_client.model.numbers_lookup_request import NumbersLookupRequest
from smscx_client.model.numbers_lookup_response import NumbersLookupResponse
from smscx_client.model.numbers_validate_request import NumbersValidateRequest
from smscx_client.model.numbers_validate_response import NumbersValidateResponse
from smscx_client.model.renew_rent_request import RenewRentRequest
from smscx_client.model.rent_number_request import RentNumberRequest
from smscx_client.model.rent_number_response import RentNumberResponse
from smscx_client.model.rent_numbers_response import RentNumbersResponse
from smscx_client.model.rented_numbers_response import RentedNumbersResponse


class NumbersApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.cancel_rent_endpoint = _Endpoint(
            settings={
                'response_type': (CancelRentResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent/{rentId}',
                'operation_id': 'cancel_rent',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'rent_id',
                ],
                'required': [
                    'rent_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'rent_id',
                ]
            },
            root_map={
                'validations': {
                    ('rent_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'rent_id':
                        (str,),
                },
                'attribute_map': {
                    'rent_id': 'rentId',
                },
                'location_map': {
                    'rent_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_available_numbers_endpoint = _Endpoint(
            settings={
                'response_type': (RentNumbersResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent/available/{countryIso}',
                'operation_id': 'get_available_numbers',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'country_iso',
                ],
                'required': [
                    'country_iso',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'country_iso',
                ]
            },
            root_map={
                'validations': {
                    ('country_iso',): {
                        'max_length': 2,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'country_iso':
                        (str,),
                },
                'attribute_map': {
                    'country_iso': 'countryIso',
                },
                'location_map': {
                    'country_iso': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_bulk_lookup_status_endpoint = _Endpoint(
            settings={
                'response_type': (NumbersBulkLookupResult,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/lookup/lookupBulkId/{lookupBulkId}',
                'operation_id': 'get_bulk_lookup_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'lookup_bulk_id',
                ],
                'required': [
                    'lookup_bulk_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'lookup_bulk_id',
                ]
            },
            root_map={
                'validations': {
                    ('lookup_bulk_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'lookup_bulk_id':
                        (str,),
                },
                'attribute_map': {
                    'lookup_bulk_id': 'lookupBulkId',
                },
                'location_map': {
                    'lookup_bulk_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_inbound_sms_endpoint = _Endpoint(
            settings={
                'response_type': (GetInboundSMSResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent/{rentId}/inbound',
                'operation_id': 'get_inbound_sms',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'rent_id',
                ],
                'required': [
                    'rent_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'rent_id',
                ]
            },
            root_map={
                'validations': {
                    ('rent_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'rent_id':
                        (str,),
                },
                'attribute_map': {
                    'rent_id': 'rentId',
                },
                'location_map': {
                    'rent_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_rent_status_endpoint = _Endpoint(
            settings={
                'response_type': (GetRentStatusResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent/{rentId}',
                'operation_id': 'get_rent_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'rent_id',
                ],
                'required': [
                    'rent_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'rent_id',
                ]
            },
            root_map={
                'validations': {
                    ('rent_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'rent_id':
                        (str,),
                },
                'attribute_map': {
                    'rent_id': 'rentId',
                },
                'location_map': {
                    'rent_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_rented_numbers_endpoint = _Endpoint(
            settings={
                'response_type': (RentedNumbersResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent',
                'operation_id': 'get_rented_numbers',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_single_lookup_status_endpoint = _Endpoint(
            settings={
                'response_type': (DataNumberLookup,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/lookup/lookupId/{lookupId}',
                'operation_id': 'get_single_lookup_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'lookup_id',
                ],
                'required': [
                    'lookup_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'lookup_id',
                ]
            },
            root_map={
                'validations': {
                    ('lookup_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'lookup_id':
                        (str,),
                },
                'attribute_map': {
                    'lookup_id': 'lookupId',
                },
                'location_map': {
                    'lookup_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.lookup_number_endpoint = _Endpoint(
            settings={
                'response_type': (NumberLookupResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/lookup/{phoneNumber}',
                'operation_id': 'lookup_number',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'phone_number',
                ],
                'required': [
                    'phone_number',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'phone_number':
                        (str,),
                },
                'attribute_map': {
                    'phone_number': 'phoneNumber',
                },
                'location_map': {
                    'phone_number': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.lookup_numbers_endpoint = _Endpoint(
            settings={
                'response_type': (NumbersLookupResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/lookup',
                'operation_id': 'lookup_numbers',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'numbers_lookup_request',
                ],
                'required': [
                    'numbers_lookup_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'numbers_lookup_request':
                        (NumbersLookupRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'numbers_lookup_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.renew_rent_endpoint = _Endpoint(
            settings={
                'response_type': (RentNumberResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent/{rentId}',
                'operation_id': 'renew_rent',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'rent_id',
                    'renew_rent_request',
                ],
                'required': [
                    'rent_id',
                    'renew_rent_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'rent_id',
                ]
            },
            root_map={
                'validations': {
                    ('rent_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'rent_id':
                        (str,),
                    'renew_rent_request':
                        (RenewRentRequest,),
                },
                'attribute_map': {
                    'rent_id': 'rentId',
                },
                'location_map': {
                    'rent_id': 'path',
                    'renew_rent_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.rent_number_endpoint = _Endpoint(
            settings={
                'response_type': (RentNumberResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/rent',
                'operation_id': 'rent_number',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'rent_number_request',
                ],
                'required': [
                    'rent_number_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'rent_number_request':
                        (RentNumberRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'rent_number_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.validate_number_endpoint = _Endpoint(
            settings={
                'response_type': (NumberValidateResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/validate/{phoneNumber}',
                'operation_id': 'validate_number',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'phone_number',
                ],
                'required': [
                    'phone_number',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'phone_number':
                        (str,),
                },
                'attribute_map': {
                    'phone_number': 'phoneNumber',
                },
                'location_map': {
                    'phone_number': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.validate_numbers_endpoint = _Endpoint(
            settings={
                'response_type': (NumbersValidateResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/numbers/validate',
                'operation_id': 'validate_numbers',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'numbers_validate_request',
                ],
                'required': [
                    'numbers_validate_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'numbers_validate_request':
                        (NumbersValidateRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'numbers_validate_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def cancel_rent(
        self,
        rent_id,
        **kwargs
    ):
        """Cancel rent for phone number  # noqa: E501

        Cancel rent for a phone number. Phone numbers rentals can be canceled within the first 30 minutes of renting period. Your account will be credited for the phone number rental cost.      
### Errors for DELETE `/numbers/rent/{rentId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1221  |  invalid_param  |  Invalid parameter `rentId` |  
|  403 | 1227  |  access_denied  |  Cannot cancel this rent. More than 30 minutes passed from start of renting period |  
|  404 | 1223  |  not_found  |  Rent ID not found |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_rent(rent_id, async_req=True)
        >>> result = thread.get()

        Args:
            rent_id (str): Identifier of the rental operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CancelRentResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['rent_id'] = \
            rent_id
        return self.cancel_rent_endpoint.call_with_http_info(**kwargs)

    def get_available_numbers(
        self,
        country_iso,
        **kwargs
    ):
        """Get available numbers for rent  # noqa: E501

        Get the list of available phone numbers for rent       
### Errors for GET `/numbers/rent/available/{countryIso}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 2003  |  invalid_param  |  Country ISO provided is invalid |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_available_numbers(country_iso, async_req=True)
        >>> result = thread.get()

        Args:
            country_iso (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RentNumbersResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['country_iso'] = \
            country_iso
        return self.get_available_numbers_endpoint.call_with_http_info(**kwargs)

    def get_bulk_lookup_status(
        self,
        lookup_bulk_id,
        **kwargs
    ):
        """Get Bulk Lookup result  # noqa: E501

        Get details of a bulk phone number lookup.        
### Errors for GET `/numbers/lookup/lookupBulkId/{lookupBulkId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 400 | 1218 | not_found | The lookupBulkId provided is invalid |  
| 404 | 1220 | invalid_param | Lookup Bulk ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_bulk_lookup_status(lookup_bulk_id, async_req=True)
        >>> result = thread.get()

        Args:
            lookup_bulk_id (str): Identifier of the bulk number lookup campaign

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NumbersBulkLookupResult
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['lookup_bulk_id'] = \
            lookup_bulk_id
        return self.get_bulk_lookup_status_endpoint.call_with_http_info(**kwargs)

    def get_inbound_sms(
        self,
        rent_id,
        **kwargs
    ):
        """Get inbound SMS from rented number  # noqa: E501

        Get a list of SMS received on the rented phone number.      
### Errors for GET `/numbers/rent/{rentId}/inbound`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1221  |  invalid_param  |  Invalid parameter `rentId` |  
|  404 | 1223  |  not_found  |  Rent ID not found |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_inbound_sms(rent_id, async_req=True)
        >>> result = thread.get()

        Args:
            rent_id (str): Identifier of the rental operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetInboundSMSResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['rent_id'] = \
            rent_id
        return self.get_inbound_sms_endpoint.call_with_http_info(**kwargs)

    def get_rent_status(
        self,
        rent_id,
        **kwargs
    ):
        """Get status of rent  # noqa: E501

        Get details of an existing rental.      
### Errors for GET `/numbers/rent/{rentId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1221  |  invalid_param  |  Invalid parameter `rentId` |  
|  404 | 1223  |  not_found  |  Rent ID not found |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_rent_status(rent_id, async_req=True)
        >>> result = thread.get()

        Args:
            rent_id (str): Identifier of the rental operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetRentStatusResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['rent_id'] = \
            rent_id
        return self.get_rent_status_endpoint.call_with_http_info(**kwargs)

    def get_rented_numbers(
        self,
        **kwargs
    ):
        """Get list of your rented numbers  # noqa: E501

        Get the list of your rented phone numbers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_rented_numbers(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RentedNumbersResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_rented_numbers_endpoint.call_with_http_info(**kwargs)

    def get_single_lookup_status(
        self,
        lookup_id,
        **kwargs
    ):
        """Get Single Lookup result  # noqa: E501

        Get details of a single number lookup.      
### Errors for GET `/numbers/lookup/lookupId/{lookupId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 400 | 1217 | invalid_param | The lookupId provided is invalid |  
| 404 | 1219 | not_found | Lookup  ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_single_lookup_status(lookup_id, async_req=True)
        >>> result = thread.get()

        Args:
            lookup_id (str): Identifier of the number lookup

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DataNumberLookup
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['lookup_id'] = \
            lookup_id
        return self.get_single_lookup_status_endpoint.call_with_http_info(**kwargs)

    def lookup_number(
        self,
        phone_number,
        **kwargs
    ):
        """Lookup number  # noqa: E501

        Lookup a single phone number, provided in international E.164 format. Returns info about status of the number (ACTIVE, ABSENT), if the phone number is ported, roaming, original and current network operator.    The endpoint returns error if phone number is invalid.    ### Statuses of phone number lookup  | Status | Description |  
|:------------:|:------------|  | ACTIVE | Phone number is reachable |  | ABSENT | Phone number is not reachable |  | BARRED | Phone number has a block from their operator |  | UNKNOWN | Unknown subscriber. Phone number is not reachable |  | FAILED | Lookup for this phone number failed |    
### Errors for GET `/numbers/lookup/{phoneNumber}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 400 | 1207 | invalid_param | The phone number is invalid |  
| 403 | 1214 | no_coverage | No coverage or restricted destination |  
| 400 | 1113 | insufficient_credit | Insufficient credit |  
| 400 | 1114 | insufficient_credit | Credit limit reached. To increase the credit limit, please contact your account manager |  
| 400 | 1212 | invalid_param | Invalid request parameters |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lookup_number(phone_number, async_req=True)
        >>> result = thread.get()

        Args:
            phone_number (str): Phone number in international E.164 format (eg. **+33612424105**). The leading plus sign of the international format can be set as is, ommited or url encoded. The API will automatically format and set the plus sign.   The following values are considered valid:   - +33612424105 - 33612424105 - %2B33612424105

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NumberLookupResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['phone_number'] = \
            phone_number
        return self.lookup_number_endpoint.call_with_http_info(**kwargs)

    def lookup_numbers(
        self,
        numbers_lookup_request,
        **kwargs
    ):
        """Lookup numbers in bulk  # noqa: E501

        Lookup a list of phone numbers. The result of the bulk phone lookup: status of the number (ACTIVE, ABSENT), if the phone numbers are ported, roaming, original and current network operator. You can lookup in bulk up to **40.000 phone numbers**.    The endpoint does not return error if phone numbers are invalid.    <a name=\"lookup-statuses\"></a>  ### Statuses of phone number lookup  | Status | Description |  
|:------------:|:------------|  | ACTIVE | Phone number is reachable |  | ABSENT | Phone number is not reachable |  | BARRED | Phone number has a block from their operator |  | UNKNOWN | Unknown subscriber. Phone number is not reachable |  | FAILED | Lookup for this phone number failed |    
### Errors for POST `/numbers/lookup`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 400 | 1203 | invalid_param | The parameter 'phoneNumbers' is empty or not set |  
| 400 | 1208 | invalid_param | The parameter 'phoneNumbers' must be an array of phone numbers |  
| 400 | 1205 | invalid_param | The phone numbers array is too big (max. allowed: 40000 numbers) |  
| 400 | 1209 | invalid_param | The parameter 'lookupCallbackUrl' is not a valid URL |  
| 403 | 1214 | no_coverage | No coverage or restricted destination |  
| 400 | 1216 | invalid_param | No valid numbers provided or no coverage |  
| 400 | 1113 | insufficient_credit | Insufficient credit |  
| 400 | 1114 | insufficient_credit | Credit limit reached. To increase the credit limit, please contact your account manager |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lookup_numbers(numbers_lookup_request, async_req=True)
        >>> result = thread.get()

        Args:
            numbers_lookup_request (NumbersLookupRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NumbersLookupResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['numbers_lookup_request'] = \
            numbers_lookup_request
        return self.lookup_numbers_endpoint.call_with_http_info(**kwargs)

    def renew_rent(
        self,
        rent_id,
        renew_rent_request,
        **kwargs
    ):
        """Renew rent for phone number  # noqa: E501

        Renew the rental of a phone number.      
### Errors for PATCH `/numbers/rent/{rentId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1221  |  invalid_param  |  Invalid parameter `rentId` |  

|  400 | 1224  |  invalid_param  |  Rent period is invalid (1, 7 or 30 days) |  

|  400 | 1225  |  invalid_param  |  Parameter `autorenew` must be of type boolean |  

|  400 | 1226  |  invalid_param  |  The parameter `callbackUrl` is not a valid url |  

|  400 | 1229  |  invalid_param  |  Rent period is not between min and max period allowed for this number |  
|  403 | 1228  |  access_denied  |  The rent cannot be renewed (rent already expired or phone number will not be available in the future) |  
|  404 | 1223  |  not_found  |  Rent ID not found |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.renew_rent(rent_id, renew_rent_request, async_req=True)
        >>> result = thread.get()

        Args:
            rent_id (str): Identifier of the rental operation
            renew_rent_request (RenewRentRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RentNumberResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['rent_id'] = \
            rent_id
        kwargs['renew_rent_request'] = \
            renew_rent_request
        return self.renew_rent_endpoint.call_with_http_info(**kwargs)

    def rent_number(
        self,
        rent_number_request,
        **kwargs
    ):
        """Rent phone number  # noqa: E501

        Rent a phone number for a period of time (1, 7 or 30 days).       
### Errors for POST `/numbers/rent`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1222  |  invalid_param  |  Invalid parameter `numberId` |  

|  400 | 1224  |  invalid_param  |  Rent period is invalid (1, 7 or 30 days) |  

|  400 | 1225  |  invalid_param  |  Parameter `autorenew` must be of type boolean |  

|  400 | 1226  |  invalid_param  |  The parameter `callbackUrl` is not a valid url |  

|  400 | 1229  |  invalid_param  |  Rent period is not between min and max period allowed for this number |  

|  400 | 1113  |  insufficient_credit  |  Insufficient credit |  
|  403 | 1231  |  access_denied  |  Cannot rent this phone number (already rented by someone else) |  
|  404 | 1230  |  not_found  |  Number ID not found or number is not available for rent anymore|    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rent_number(rent_number_request, async_req=True)
        >>> result = thread.get()

        Args:
            rent_number_request (RentNumberRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RentNumberResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['rent_number_request'] = \
            rent_number_request
        return self.rent_number_endpoint.call_with_http_info(**kwargs)

    def validate_number(
        self,
        phone_number,
        **kwargs
    ):
        """Validate number  # noqa: E501

        Validates a single phone number, provided in international E.164 format.    The endpoint returns error if phone number is invalid.    
### Errors for GET `/numbers/validate/{phoneNumber}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1207  |  invalid_param  |  The phone number is invalid  |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_number(phone_number, async_req=True)
        >>> result = thread.get()

        Args:
            phone_number (str): Phone number in international E.164 format (eg. **+33612424105**). The leading plus sign of the international format can be set as is, ommited or url encoded. The API will automatically format and set the plus sign.   The following values are considered valid:   - +33612424105 - 33612424105 - %2B33612424105

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NumberValidateResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['phone_number'] = \
            phone_number
        return self.validate_number_endpoint.call_with_http_info(**kwargs)

    def validate_numbers(
        self,
        numbers_validate_request,
        **kwargs
    ):
        """Validate numbers in bulk  # noqa: E501

        Validate a list of phone numbers. You can validate in bulk up to **40.000 phone numbers**.    The endpoint does not return error if phone numbers are invalid.    This method will validate the list of phone numbers and return an array of objects, **preserving the order of the list provided** and not excluding the invalid phone numbers.     An invalid phone number will have the parameter `invalid` with value `true` in the response object.      
### Errors for POST `/numbers/validate`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1203  |  invalid_param  |  The parameter `phoneNumbers` is empty or not set |  

|  400 | 1208  |  invalid_param  |  The parameter `phoneNumbers` must be an array of phone numbers |  
| 400 | 1205 | invalid_param | The phone numbers array is too big (max. allowed: 40000 numbers) |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_numbers(numbers_validate_request, async_req=True)
        >>> result = thread.get()

        Args:
            numbers_validate_request (NumbersValidateRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NumbersValidateResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['numbers_validate_request'] = \
            numbers_validate_request
        return self.validate_numbers_endpoint.call_with_http_info(**kwargs)




import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.add_contacts_to_group_request import AddContactsToGroupRequest
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.optouts_delete_response import OptoutsDeleteResponse
from smscx_client.model.optouts_list_response import OptoutsListResponse
from smscx_client.model.optouts_new_response import OptoutsNewResponse


class OptoutsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.add_contact_to_optouts_list_endpoint = _Endpoint(
            settings={
                'response_type': (OptoutsNewResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/optouts',
                'operation_id': 'add_contact_to_optouts_list',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'add_contacts_to_group_request',
                ],
                'required': [
                    'add_contacts_to_group_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'add_contacts_to_group_request':
                        (AddContactsToGroupRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'add_contacts_to_group_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_contact_from_optouts_list_endpoint = _Endpoint(
            settings={
                'response_type': (OptoutsDeleteResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/optouts/{optoutId}',
                'operation_id': 'delete_contact_from_optouts_list',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'optout_id',
                ],
                'required': [
                    'optout_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'optout_id':
                        (int,),
                },
                'attribute_map': {
                    'optout_id': 'optoutId',
                },
                'location_map': {
                    'optout_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_optouts_to_csv_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/optouts/csv',
                'operation_id': 'export_optouts_to_csv',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/csv',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_optouts_to_xlsx_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/optouts/xlsx',
                'operation_id': 'export_optouts_to_xlsx',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_optouts_list_endpoint = _Endpoint(
            settings={
                'response_type': (OptoutsListResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/optouts',
                'operation_id': 'get_optouts_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def add_contact_to_optouts_list(
        self,
        add_contacts_to_group_request,
        **kwargs
    ):
        """Add contact to optouts list  # noqa: E501

        Add contacts to the optout list. Even if you mistakenly send SMS to a contact that is in the optouts list, the SMS.CX API will detect the contact and not send any messages to unsubscribed contacts. Also, you will not be billed - sending a SMS to an unsubscribed contact will be saved as 0 cost.    
### Errors for POST `/optouts`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1203  |  invalid_param  |  The parameter `phoneNumbers` is empty or not set |  

|  400 | 1208  |  invalid_param  |  The parameter `phoneNumbers` must be an array of phone numbers  |    

|  400 | 1210  |  invalid_param  |  The phone numbers provided are invalid |  

|  400 | 1441  |  invalid_param  | No valid phone numbers were provided or already in the optout list |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_contact_to_optouts_list(add_contacts_to_group_request, async_req=True)
        >>> result = thread.get()

        Args:
            add_contacts_to_group_request (AddContactsToGroupRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OptoutsNewResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['add_contacts_to_group_request'] = \
            add_contacts_to_group_request
        return self.add_contact_to_optouts_list_endpoint.call_with_http_info(**kwargs)

    def delete_contact_from_optouts_list(
        self,
        optout_id,
        **kwargs
    ):
        """Delete contact from optouts list  # noqa: E501

        Removes a contact from the optout list if a valid phone number identifier was provided.    Only contacts that were added with the API can be deleted.      Contacts that opted out via `link` cannot be deleted.    
### Errors for DELETE `/optouts/{optoutId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1202  |  not_found  |  Phone number ID not found  
|  403 | 1443  |  access_denied  |  Cannot delete this phone number from the optout list because it was added via optout type `link`. Allowed optout type to delete: `admin` |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_contact_from_optouts_list(optout_id, async_req=True)
        >>> result = thread.get()

        Args:
            optout_id (int): Identifier of the phone number in the optout list

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OptoutsDeleteResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['optout_id'] = \
            optout_id
        return self.delete_contact_from_optouts_list_endpoint.call_with_http_info(**kwargs)

    def export_optouts_to_csv(
        self,
        **kwargs
    ):
        """Export optouts to CSV  # noqa: E501

        Exports the contacts from the optout list to a CSV file.    If the optout list is empty, an empty CSV file is returned (with first line headers).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_optouts_to_csv(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.export_optouts_to_csv_endpoint.call_with_http_info(**kwargs)

    def export_optouts_to_xlsx(
        self,
        **kwargs
    ):
        """Export optouts to XLSX  # noqa: E501

        Exports the contacts from the optout list to a XLSX file (Excel).    If the optout list is empty, an empty XLSX file is returned (with first line headers).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_optouts_to_xlsx(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.export_optouts_to_xlsx_endpoint.call_with_http_info(**kwargs)

    def get_optouts_list(
        self,
        **kwargs
    ):
        """Get optouts list  # noqa: E501

        Retrieves the list of existing contacts that opted out. The optouts are returned sorted by creation date, with the most recent optout contact appearing first.    If no optouts are available, an empty data object is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_optouts_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OptoutsListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_optouts_list_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.data_otp import DataOtp
globals()['DataOtp'] = DataOtp
from smscx_client.model.call_back_request_otp_update import CallBackRequestOtpUpdate


class TestCallBackRequestOtpUpdate(unittest.TestCase):
    """CallBackRequestOtpUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCallBackRequestOtpUpdate(self):
        """Test CallBackRequestOtpUpdate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CallBackRequestOtpUpdate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_cancel_rent import InfoCancelRent
globals()['InfoCancelRent'] = InfoCancelRent
from smscx_client.model.cancel_rent_response import CancelRentResponse


class TestCancelRentResponse(unittest.TestCase):
    """CancelRentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCancelRentResponse(self):
        """Test CancelRentResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CancelRentResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_template import DataTemplate
globals()['DataTemplate'] = DataTemplate
from smscx_client.model.template_details_response import TemplateDetailsResponse


class TestTemplateDetailsResponse(unittest.TestCase):
    """TemplateDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTemplateDetailsResponse(self):
        """Test TemplateDetailsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TemplateDetailsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_sms import DataSms
from smscx_client.model.info import Info
globals()['DataSms'] = DataSms
globals()['Info'] = Info
from smscx_client.model.send_sms_message_response import SendSmsMessageResponse


class TestSendSmsMessageResponse(unittest.TestCase):
    """SendSmsMessageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendSmsMessageResponse(self):
        """Test SendSmsMessageResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SendSmsMessageResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_applications_list import DataApplicationsList
globals()['DataApplicationsList'] = DataApplicationsList
from smscx_client.model.applications_list_response import ApplicationsListResponse


class TestApplicationsListResponse(unittest.TestCase):
    """ApplicationsListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApplicationsListResponse(self):
        """Test ApplicationsListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApplicationsListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_shortlink_list import DataShortlinkList
globals()['DataShortlinkList'] = DataShortlinkList
from smscx_client.model.shortlinks_list_response import ShortlinksListResponse


class TestShortlinksListResponse(unittest.TestCase):
    """ShortlinksListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testShortlinksListResponse(self):
        """Test ShortlinksListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ShortlinksListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_numbers_validate import DataNumbersValidate
from smscx_client.model.info_numbers_validate import InfoNumbersValidate
globals()['DataNumbersValidate'] = DataNumbersValidate
globals()['InfoNumbersValidate'] = InfoNumbersValidate
from smscx_client.model.numbers_validate_response import NumbersValidateResponse


class TestNumbersValidateResponse(unittest.TestCase):
    """NumbersValidateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNumbersValidateResponse(self):
        """Test NumbersValidateResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NumbersValidateResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.rental_cost import RentalCost
    globals()['RentalCost'] = RentalCost


class DataRentedNumbers(ModelNormal):


    allowed_values = {
        ('rent_period',): {
            '1': 1,
            '7': 7,
            '30': 30,
        },
        ('sms',): {
            'INBOUND': "inbound",
            'OUTBOUND': "outbound",
        },
        ('min_rent',): {
            'None': None,
            '1': "1",
            '7': "7",
            '30': "30",
        },
        ('max_rent',): {
            'None': None,
            '1': "1",
            '7': "7",
            '30': "30",
        },
    }

    validations = {
        ('rent_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'rent_id': (str,),  # noqa: E501
            'rent_cost': (float,),  # noqa: E501
            'setup_cost': (float,),  # noqa: E501
            'rent_period': (int,),  # noqa: E501
            'rent_start': (datetime,),  # noqa: E501
            'rent_end': (datetime,),  # noqa: E501
            'phone_number': (str,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            'network_operator': (str,),  # noqa: E501
            'auto_renew': (bool,),  # noqa: E501
            'sms': ([str],),  # noqa: E501
            'voice': ([str],),  # noqa: E501
            'min_rent': (str, none_type,),  # noqa: E501
            'max_rent': (str, none_type,),  # noqa: E501
            'rental_cost': (RentalCost,),  # noqa: E501
            'inbound_sms_cost': (float,),  # noqa: E501
            'callback_url': (str, none_type,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'rent_id': 'rentId',  # noqa: E501
        'rent_cost': 'rentCost',  # noqa: E501
        'setup_cost': 'setupCost',  # noqa: E501
        'rent_period': 'rentPeriod',  # noqa: E501
        'rent_start': 'rentStart',  # noqa: E501
        'rent_end': 'rentEnd',  # noqa: E501
        'phone_number': 'phoneNumber',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        'network_operator': 'networkOperator',  # noqa: E501
        'auto_renew': 'autoRenew',  # noqa: E501
        'sms': 'sms',  # noqa: E501
        'voice': 'voice',  # noqa: E501
        'min_rent': 'minRent',  # noqa: E501
        'max_rent': 'maxRent',  # noqa: E501
        'rental_cost': 'rentalCost',  # noqa: E501
        'inbound_sms_cost': 'inboundSmsCost',  # noqa: E501
        'callback_url': 'callbackUrl',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, rent_id, rent_cost, setup_cost, rent_period, rent_start, rent_end, phone_number, country_iso, network_operator, auto_renew, sms, voice, min_rent, max_rent, rental_cost, inbound_sms_cost, callback_url, *args, **kwargs):  # noqa: E501
        """DataRentedNumbers - a model

        Args:
            rent_id (str): Unique identifier of the rent operation
            rent_cost (float): Cost of renting the phone number for the period chosen
            setup_cost (float): One time setup fee for the rented phone number (if applicable)
            rent_period (int): Rental period of the phone number (in days)
            rent_start (datetime): Start date and time of the rental period (UTC)
            rent_end (datetime): End date and time of the rental period (UTC)
            phone_number (str): Phone number that is rented in international E.164 format
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard. Eg. `DE`, `FR`, `IT`
            network_operator (str): Network operator of the phone number
            auto_renew (bool): Status of the auto renewal setting for this number rental
            sms ([str]): SMS features that the phone number supports (inbound or outbound SMS)
            voice ([str]): Voice features that the phone number supports
            min_rent (str, none_type): Minimum period that this phone number must be rented (in days)
            max_rent (str, none_type): Maximum period that this phone number can be rented (in days)
            rental_cost (RentalCost):
            inbound_sms_cost (float): Cost for receiving a SMS on this phone number (most of the time receiving is free, meaning this is has value 0)
            callback_url (str, none_type): Callback URL (or webhook) to get the received SMS on the rented phone number


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.rent_id = rent_id
        self.rent_cost = rent_cost
        self.setup_cost = setup_cost
        self.rent_period = rent_period
        self.rent_start = rent_start
        self.rent_end = rent_end
        self.phone_number = phone_number
        self.country_iso = country_iso
        self.network_operator = network_operator
        self.auto_renew = auto_renew
        self.sms = sms
        self.voice = voice
        self.min_rent = min_rent
        self.max_rent = max_rent
        self.rental_cost = rental_cost
        self.inbound_sms_cost = inbound_sms_cost
        self.callback_url = callback_url
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, rent_id, rent_cost, setup_cost, rent_period, rent_start, rent_end, phone_number, country_iso, network_operator, auto_renew, sms, voice, min_rent, max_rent, rental_cost, inbound_sms_cost, callback_url, *args, **kwargs):  # noqa: E501
        """DataRentedNumbers - a model

        Args:
            rent_id (str): Unique identifier of the rent operation
            rent_cost (float): Cost of renting the phone number for the period chosen
            setup_cost (float): One time setup fee for the rented phone number (if applicable)
            rent_period (int): Rental period of the phone number (in days)
            rent_start (datetime): Start date and time of the rental period (UTC)
            rent_end (datetime): End date and time of the rental period (UTC)
            phone_number (str): Phone number that is rented in international E.164 format
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard. Eg. `DE`, `FR`, `IT`
            network_operator (str): Network operator of the phone number
            auto_renew (bool): Status of the auto renewal setting for this number rental
            sms ([str]): SMS features that the phone number supports (inbound or outbound SMS)
            voice ([str]): Voice features that the phone number supports
            min_rent (str, none_type): Minimum period that this phone number must be rented (in days)
            max_rent (str, none_type): Maximum period that this phone number can be rented (in days)
            rental_cost (RentalCost):
            inbound_sms_cost (float): Cost for receiving a SMS on this phone number (most of the time receiving is free, meaning this is has value 0)
            callback_url (str, none_type): Callback URL (or webhook) to get the received SMS on the rented phone number


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.rent_id = rent_id
        self.rent_cost = rent_cost
        self.setup_cost = setup_cost
        self.rent_period = rent_period
        self.rent_start = rent_start
        self.rent_end = rent_end
        self.phone_number = phone_number
        self.country_iso = country_iso
        self.network_operator = network_operator
        self.auto_renew = auto_renew
        self.sms = sms
        self.voice = voice
        self.min_rent = min_rent
        self.max_rent = max_rent
        self.rental_cost = rental_cost
        self.inbound_sms_cost = inbound_sms_cost
        self.callback_url = callback_url
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.custom_fields_obj import CustomFieldsObj
globals()['CustomFieldsObj'] = CustomFieldsObj
from smscx_client.model.group_add_custom_fields import GroupAddCustomFields


class TestGroupAddCustomFields(unittest.TestCase):
    """GroupAddCustomFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGroupAddCustomFields(self):
        """Test GroupAddCustomFields"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GroupAddCustomFields()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_channel_response import ReportsSummaryChannelResponse
from smscx_client.model.reports_summary_country_response import ReportsSummaryCountryResponse
from smscx_client.model.reports_summary_delivery_response import ReportsSummaryDeliveryResponse
from smscx_client.model.reports_summary_source_response import ReportsSummarySourceResponse
from smscx_client.model.reports_summary_traffic_response import ReportsSummaryTrafficResponse
from smscx_client.model.reports_summary_traffic_response_data_value import ReportsSummaryTrafficResponseDataValue
globals()['ReportsSummaryChannelResponse'] = ReportsSummaryChannelResponse
globals()['ReportsSummaryCountryResponse'] = ReportsSummaryCountryResponse
globals()['ReportsSummaryDeliveryResponse'] = ReportsSummaryDeliveryResponse
globals()['ReportsSummarySourceResponse'] = ReportsSummarySourceResponse
globals()['ReportsSummaryTrafficResponse'] = ReportsSummaryTrafficResponse
globals()['ReportsSummaryTrafficResponseDataValue'] = ReportsSummaryTrafficResponseDataValue
from smscx_client.model.get_summary_reports200_response import GetSummaryReports200Response


class TestGetSummaryReports200Response(unittest.TestCase):
    """GetSummaryReports200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetSummaryReports200Response(self):
        """Test GetSummaryReports200Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetSummaryReports200Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_shortlink_detail import InfoShortlinkDetail


class TestInfoShortlinkDetail(unittest.TestCase):
    """InfoShortlinkDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInfoShortlinkDetail(self):
        """Test InfoShortlinkDetail"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InfoShortlinkDetail()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_receive_sms import DataReceiveSms
from smscx_client.model.info_inbound_sms import InfoInboundSms
from smscx_client.model.paging import Paging
globals()['DataReceiveSms'] = DataReceiveSms
globals()['InfoInboundSms'] = InfoInboundSms
globals()['Paging'] = Paging
from smscx_client.model.get_inbound_sms_response import GetInboundSMSResponse


class TestGetInboundSMSResponse(unittest.TestCase):
    """GetInboundSMSResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetInboundSMSResponse(self):
        """Test GetInboundSMSResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetInboundSMSResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_conversation_reply import DataConversationReply
from smscx_client.model.info_conversation_reply import InfoConversationReply
globals()['DataConversationReply'] = DataConversationReply
globals()['InfoConversationReply'] = InfoConversationReply
from smscx_client.model.conversation_reply_sms_response import ConversationReplySmsResponse


class TestConversationReplySmsResponse(unittest.TestCase):
    """ConversationReplySmsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConversationReplySmsResponse(self):
        """Test ConversationReplySmsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConversationReplySmsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
